[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,80 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/__stf/utility/run_once.cuh>
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
int main()
|
||||
{
|
||||
context ctx;
|
||||
|
||||
const int N = 16;
|
||||
size_t niter = 12;
|
||||
|
||||
int A[N];
|
||||
|
||||
for (int i = 0; i < N; i++)
|
||||
{
|
||||
A[i] = 2 * i + 1;
|
||||
}
|
||||
|
||||
auto lres = ctx.logical_data(A);
|
||||
|
||||
for (size_t k = 0; k < niter; k++)
|
||||
{
|
||||
auto ltmp = ctx.logical_data(lres.shape());
|
||||
ctx.parallel_for(ltmp.shape(), ltmp.write())->*[] __device__(size_t i, auto tmp) {
|
||||
tmp(i) = i;
|
||||
};
|
||||
|
||||
ctx.parallel_for(lres.shape(), ltmp.read(), lres.rw())->*[] __device__(size_t i, auto tmp, auto res) {
|
||||
res(i) += tmp(i);
|
||||
};
|
||||
}
|
||||
|
||||
for (size_t k = 0; k < niter; k++)
|
||||
{
|
||||
auto ltmp = run_once()->*[&]() {
|
||||
// Ensure this is only done once !
|
||||
static bool done = false;
|
||||
EXPECT(!done);
|
||||
done = true;
|
||||
|
||||
auto ltmp = ctx.logical_data(lres.shape());
|
||||
ctx.parallel_for(ltmp.shape(), ltmp.write())->*[] __device__(size_t i, auto tmp) {
|
||||
tmp(i) = i;
|
||||
};
|
||||
return ltmp;
|
||||
};
|
||||
|
||||
auto ltmp2 = run_once(size_t(k % 4))->*[&](size_t val) {
|
||||
// fprintf(stderr, "COMPUTE FOR %ld\n", val);
|
||||
|
||||
auto ltmp = ctx.logical_data(lres.shape());
|
||||
ctx.parallel_for(ltmp.shape(), ltmp.write())->*[val] __device__(size_t i, auto tmp) {
|
||||
tmp(i) = val;
|
||||
};
|
||||
return ltmp;
|
||||
};
|
||||
|
||||
ctx.parallel_for(lres.shape(), ltmp.read(), lres.rw())->*[] __device__(size_t i, auto tmp, auto res) {
|
||||
res(i) += tmp(i);
|
||||
};
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
|
||||
for (int i = 0; i < N; i++)
|
||||
{
|
||||
EXPECT(A[i] == (2 * i + 1) + 2 * i * niter);
|
||||
}
|
||||
}
|
||||
Reference in New Issue
Block a user